==> SampLin-1.3.1.tar.gz: SampLin-1.3.1/src/sqwt/dlg/GraphLegendData.moc.cpp <==
/****************************************************************************
** GraphLegendData meta object code from reading C++ file 'GraphLegendData.h'
**
** Created: Mon Feb 22 21:45:00 1999
**      by: The Qt Meta Object Compiler ($Revision: 2.25.2.11 $)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#if !defined(Q_MOC_OUTPUT_REVISION)
#define Q_MOC_OUTPUT_REVISION 2
#elif Q_MOC_OUTPUT_REVISION != 2
#error "Moc format conflict - please regenerate all moc files"
#endif

#include "GraphLegendData.h"
#include <qmetaobject.h>


const char *GraphLegendData::className() const
{
    return "GraphLegendData";
}

QMetaObject *GraphLegendData::metaObj = 0;


#if QT_VERSION >= 200
static QMetaObjectInit init_GraphLegendData(&GraphLegendData::staticMetaObject);

#endif

void GraphLegendData::initMetaObject()
{
    if ( metaObj )
	return;
    if ( strcmp(QDialog::className(), "QDialog") != 0 )
	badSuperclassWarning("GraphLegendData","QDialog");

#if QT_VERSION >= 200
    staticMetaObject();
}

void GraphLegendData::staticMetaObject()
{
    if ( metaObj )
	return;
    QDialog::staticMetaObject();
#else

    QDialog::initMetaObject();
#endif

    typedef void(GraphLegendData::*m1_t0)();
    typedef void(GraphLegendData::*m1_t1)();
    m1_t0 v1_0 = &GraphLegendData::selectCFont;
    m1_t1 v1_1 = &GraphLegendData::selectLFont;
    QMetaData *slot_tbl = new QMetaData[2];
    slot_tbl[0].name = "selectCFont()";
    slot_tbl[1].name = "selectLFont()";
    slot_tbl[0].ptr = *((QMember*)&v1_0);
    slot_tbl[1].ptr = *((QMember*)&v1_1);
    metaObj = new QMetaObject( "GraphLegendData", "QDialog",
	slot_tbl, 2,
	0, 0 );
}

==> SampLin-1.5.0.tar.gz: SampLin-1.5.0/src/sqwt/dlg/GraphLegendData.moc.cpp <==
/****************************************************************************
** GraphLegendData meta object code from reading C++ file 'GraphLegendData.h'
**
** Created: Thu Sep 2 20:49:19 1999
**      by: The Qt Meta Object Compiler ($Revision: 2.25.2.12 $)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#if !defined(Q_MOC_OUTPUT_REVISION)
#define Q_MOC_OUTPUT_REVISION 2
#elif Q_MOC_OUTPUT_REVISION != 2
#error "Moc format conflict - please regenerate all moc files"
#endif

#include "GraphLegendData.h"
#include <qmetaobject.h>


const char *GraphLegendData::className() const
{
    return "GraphLegendData";
}

QMetaObject *GraphLegendData::metaObj = 0;


#if QT_VERSION >= 200
static QMetaObjectInit init_GraphLegendData(&GraphLegendData::staticMetaObject);

#endif

void GraphLegendData::initMetaObject()
{
    if ( metaObj )
	return;
    if ( strcmp(QWidget::className(), "QWidget") != 0 )
	badSuperclassWarning("GraphLegendData","QWidget");

#if QT_VERSION >= 200
    staticMetaObject();
}

void GraphLegendData::staticMetaObject()
{
    if ( metaObj )
	return;
    QWidget::staticMetaObject();
#else

    QWidget::initMetaObject();
#endif

    typedef void(GraphLegendData::*m1_t0)();
    typedef void(GraphLegendData::*m1_t1)();
    m1_t0 v1_0 = &GraphLegendData::selectCFont;
    m1_t1 v1_1 = &GraphLegendData::selectLFont;
    QMetaData *slot_tbl = new QMetaData[2];
    slot_tbl[0].name = "selectCFont()";
    slot_tbl[1].name = "selectLFont()";
    slot_tbl[0].ptr = *((QMember*)&v1_0);
    slot_tbl[1].ptr = *((QMember*)&v1_1);
    metaObj = new QMetaObject( "GraphLegendData", "QWidget",
	slot_tbl, 2,
	0, 0 );
}
